#
# spec file for package wbg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           wbg
Version:        1.2.0
Release:        2.5
Summary:        Wallpaper application for layer-shell Wayland compositors
License:        MIT
Group:          System/GUI/Other
URL:            https://codeberg.org/dnkl/wbg
Source:         %{url}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.gz.sig
# https://keyserver.ubuntu.com/pks/lookup?op=get&search=0xb19964fbba09664cc81027ed5bbd4992c116573f
Source2:        %{name}.keyring
BuildRequires:  c_compiler
BuildRequires:  meson >= 0.58.0
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(tllist) >= 1.0.1
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-server)

%description
Wbg is a wallpaper setter for Wayland compositors that implement the
layer-shell protocol.

It takes a single argument, the image filename, which is displayed
scaled-to-fit on all monitors.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags}"
%meson
%meson_build

%install
%meson_install

%check
%meson_test

%files
%license LICENSE
%doc README.md
%{_bindir}/wbg

%changelog
* Mon Apr 22 2024 Joshua Smith <smolsheep@opensuse.org>
- Add keyring and signature for package.
* Fri Apr 19 2024 Joshua Smith <smolsheep@opensuse.org>
- Remove patches (fixed upstream)
  * 0001-fix-mfd-noexec-seal.patch
  * 0004-impl-layer-surface-closed-event.patch
  * 0005-mark-surface-as-opaque.patch
- Update to version 1.2.0:
  Added
  * We now hint to the compositor that the background is fully
    opaque.
  * SVG support.
  Changed
  * Image is now zoomed, rather than stretched.
  Fixed
  * Respect the layer_surface::closed() event.
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Oct 24 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add patchsets
  * 0001-fix-mfd-noexec-seal.patch
  * 0004-impl-layer-surface-closed-event.patch
  * 0005-mark-surface-as-opaque.patch
* Wed Oct 26 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 1.1.0:
  - Added:
  * webp support
  - Fixed:
  * meson: can’t use `SOURCE_DIR` in `custom_targets()`.
  * build: version script is now run in a C locale.
  * Don’t re-render frame on same-size configure events
* Sun May 29 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- use meson version >= 0.58.0 to abandon deprecated options
* Thu Mar  3 2022 Jan Engelhardt <jengelh@inai.de>
- Use released tarball with source URL
- Trim description of filler wording
* Wed Mar  2 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec (version 1.0.2)
